@@ -2,15 +2,35 @@ use std::{sync::Arc, vec};
 
 use bailongma::*;
 
+use libtaos::Taos;
+
 use clap::Clap;
 use itertools::Itertools;
 use log::{error, trace};
 use names::{Generator, Name};
 use rayon::prelude::*;
-use tokio;
 
+#[derive(Clap, Debug)]
+pub struct Cfg {
+    #[clap(long, default_value = "127.0.0.1")]
+    host: String,
+    #[clap(long, default_value = "root")]
+    user: String,
+    #[clap(long, default_value = "taosdata")]
+    pass: String,
+    #[clap(long, default_value = "prometheus")]
+    db: String,
+    #[clap(long, default_value = "6030")]
+    port: u16,
+}
+
+impl Cfg {
+    fn to_taos(&self) -> Result<Taos, libtaos::Error> {
+        Taos::new(&self.host, &self.user, &self.pass, &self.db, self.port)
+    }
+}
 /// TDengine adapter for prometheus.
-#[derive(Debug, Clone, Clap)]
+#[derive(Debug, Clap)]
 #[clap(setting = clap::AppSettings::ColoredHelp)]
 #[clap(version, author)]
 struct Opts {
@@ -40,11 +60,21 @@ struct Opts {
     /// Samples per point, so the stable rows is points * samples
     #[clap(long, default_value = "100")]
     samples: u32,
+
+    /// If in CI environment.
+    #[clap(long)]
+    ci: bool,
+    /// Wait in ci
+    #[clap(long, default_value = "1000")]
+    wait: u32,
+    /// TaosCfg values.
+    #[clap(flatten)]
+    cfg: Cfg,
 }
 
 fn random_names(len: usize) -> Vec<String> {
     let generator = Generator::with_naming(Name::Numbered);
-    generator.take(len).collect()
+    generator.map(|s| s.replace("-", "_")).take(len).collect()
 }
 
 impl Opts {
@@ -71,7 +101,7 @@ struct PromGenerator {
 }
 
 impl PromGenerator {
-    fn build_timeseries(&self, rt: &tokio::runtime::Runtime, ts_offset: i64) {
+    fn build_timeseries(&self, ts_offset: i64) {
         let interval = self.interval;
         let sample = Sample {
             value: Some(ts_offset as _),
@@ -131,7 +161,7 @@ impl PromGenerator {
             .into_par_iter()
             .for_each(|data| {
                 use tempfile::NamedTempFile;
-                std::fs::write("test.prom", &data).expect("write to file");
+                //std::fs::write("test.prom", &data).expect("write to file");
                 let url = self.endpoint.clone();
                 trace!("datalen: {}", data.len());
                 //rt.spawn_blocking(move || {
@@ -156,21 +186,16 @@ impl PromGenerator {
             });
     }
 }
-//#[tokio::main(flavor = "multi_thread", worker_threads = 10)]
-fn main() {
+
+#[tokio::main(flavor = "multi_thread")]
+async fn main() {
     let opts: Opts = Opts::parse();
+
+    //std::env::set_var("RUST_LOG", opts.level);
+    env_logger::Builder::new().filter_level(opts.level).init();
     let metrics = opts.random_metrics_names();
     let labels = opts.random_labels();
     let points = opts.random_points();
-
-    use tokio::runtime;
-
-    // This will spawn a work-stealing runtime with 4 worker threads.
-    let rt = runtime::Builder::new_multi_thread()
-        .worker_threads(opts.threads)
-        .thread_name("bench-prom")
-        .build()
-        .unwrap();
     rayon::ThreadPoolBuilder::new()
         .num_threads(opts.threads)
         .build_global()
@@ -192,6 +217,31 @@ fn main() {
     };
 
     for i in 0..opts.samples {
-        prom_g.build_timeseries(&rt, i as _);
+        prom_g.build_timeseries(i as _);
+    }
+
+    if opts.ci {
+        std::thread::sleep(std::time::Duration::from_millis(opts.wait as _));
+        let taos = opts.cfg.to_taos().expect("connection failed");
+
+        let stables = taos.query("show stables").await.unwrap();
+        use itertools::Itertools;
+        let stable_names = stables
+            .rows
+            .iter()
+            .filter_map(|row| row.first())
+            .collect_vec();
+        assert_eq!(stable_names.len(), opts.metrics);
+        for stable in stable_names {
+            let content = taos
+                .query(&format!("select * from {}", stable))
+                .await
+                .unwrap();
+            assert_eq!(
+                content.rows(),
+                (opts.samples as usize * opts.points) as usize
+            );
+            taos.exec(&format!("drop table {}", stable)).await.unwrap();
+        }
     }
 }
